@@ -27,6 +27,7 @@ It also allows setting of formatting information through conf.
 
 """
 
+import configparser
 import logging
 import logging.config
 import logging.handlers
@@ -41,8 +42,6 @@ except ImportError:
 from oslo_config import cfg
 from oslo_utils import importutils
 from oslo_utils import units
-import six
-from six import moves
 
 from oslo_log._i18n import _
 from oslo_log import _options
@@ -232,8 +231,8 @@ def _load_log_config(log_config_append):
             logging.config.fileConfig(log_config_append,
                                       disable_existing_loggers=False)
             _load_log_config.old_time = new_time
-    except (moves.configparser.Error, KeyError, os.error) as exc:
-        raise LogConfigError(log_config_append, six.text_type(exc))
+    except (configparser.Error, KeyError, os.error) as exc:
+        raise LogConfigError(log_config_append, str(exc))
 
 
 def _mutate_hook(conf, fresh):
@@ -266,8 +265,26 @@ def register_options(conf):
     conf.register_mutate_hook(_mutate_hook)
 
 
-def setup(conf, product_name, version='unknown'):
+def _fix_eventlet_logging():
+    """Properly setup logging with eventlet on native threads.
+
+    Workaround for: https://github.com/eventlet/eventlet/issues/432
+    """
+
+    # If eventlet was not loaded before call to setup assume it's not used.
+    eventlet = sys.modules.get('eventlet')
+    if eventlet:
+        import eventlet.green.threading
+        from oslo_log import pipe_mutex
+        logging.threading = eventlet.green.threading
+        logging._lock = logging.threading.RLock()
+        logging.Handler.createLock = pipe_mutex.pipe_createLock
+
+
+def setup(conf, product_name, version='unknown', *, fix_eventlet=True):
     """Setup logging for the current application."""
+    if fix_eventlet:
+        _fix_eventlet_logging()
     if conf.log_config_append:
         _load_log_config(conf.log_config_append)
     else:
@@ -388,7 +405,10 @@ def _setup_logging_from_conf(conf, project, version):
         log_root.addHandler(streamlog)
 
     if conf.use_journal:
-        journal = handlers.OSJournalHandler()
+        if syslog is None:
+            raise RuntimeError("syslog is not available on this platform")
+        facility = _find_facility(conf.syslog_log_facility)
+        journal = handlers.OSJournalHandler(facility=facility)
         log_root.addHandler(journal)
 
     if conf.use_eventlog:
@@ -413,7 +433,6 @@ def _setup_logging_from_conf(conf, project, version):
         log_root.addHandler(handler)
 
     if conf.use_syslog:
-        global syslog
         if syslog is None:
             raise RuntimeError("syslog is not available on this platform")
         facility = _find_facility(conf.syslog_log_facility)
@@ -455,6 +474,7 @@ def _setup_logging_from_conf(conf, project, version):
                                   conf.rate_limit_interval,
                                   conf.rate_limit_except)
 
+
 _loggers = {}
 
 
